@@ -1,7 +1,11 @@
-from .general import (load_mle_toolbox_config, load_yaml_config,
-                      load_json_config, load_pkl_object,
-                      determine_resource, print_framed)
-from .experiment_logger import DeepLogger
+from .general import (load_mle_toolbox_config,
+                      load_yaml_config,
+                      load_json_config,
+                      load_pkl_object,
+                      determine_resource,
+                      print_framed,
+                      get_jax_os_ready)
+from .mle_logger import MLE_Logger
 from .core import get_configs_ready, set_random_seeds, load_result_logs
 from .load_meta_log import load_meta_log, subselect_meta_log
 from .load_hyper_log import load_hyper_log, subselect_hyper_log
@@ -15,7 +19,8 @@ __all__ = [
            'load_pkl_object',
            'determine_resource',
            'print_framed',
-           'DeepLogger',
+           'get_jax_os_ready',
+           'MLE_Logger',
            'get_configs_ready',
            'set_random_seeds',
            'load_result_logs'
